# MCP Optimizer - Examples

This directory contains practical examples and prompts for using MCP Optimizer with Large Language Models (LLMs). Examples are provided in both Russian (`/ru`) and English (`/en`) languages.

## Available Examples

### 📊 Linear Programming
- **Russian**: [examples/ru/linear_programming.md](ru/linear_programming.md)
- **English**: [examples/en/linear_programming.md](en/linear_programming.md)

Examples include:
- Production optimization
- Diet planning
- Transportation problems
- Blending problems

### 👥 Assignment Problems
- **Russian**: [examples/ru/assignment_problems.md](ru/assignment_problems.md)
- **English**: [examples/en/assignment_problems.md](en/assignment_problems.md)

Examples include:
- Employee-project assignment
- Machine-order allocation
- Driver-route assignment
- Task-team distribution

### 💰 Portfolio Optimization
- **Russian**: [examples/ru/portfolio_optimization.md](ru/portfolio_optimization.md)
- **English**: [examples/en/portfolio_optimization.md](en/portfolio_optimization.md)

Examples include:
- Basic portfolio optimization
- Diversified portfolios
- Retirement planning
- Aggressive growth strategies

### 🚚 Transportation & Logistics
- **Russian**: [examples/ru/transportation_logistics.md](ru/transportation_logistics.md)
- **English**: [examples/en/transportation_logistics.md](en/transportation_logistics.md)

Examples include:
- Classic transportation problems
- Multi-product logistics
- Supply chain planning
- Fleet optimization
- Warehouse logistics
- International shipping
- Last-mile delivery
- Railway transportation

### 🎒 Knapsack Selection Problems
- **Russian**: [examples/ru/knapsack_selection.md](ru/knapsack_selection.md)
- **English**: [examples/en/knapsack_selection.md](en/knapsack_selection.md)

Examples include:
- Classic knapsack problems
- Investment project selection
- Container loading optimization
- Resource allocation
- Budget optimization
- Team formation
- Production planning
- Research project selection

### 🗺️ Routing & Scheduling
- **Russian**: [examples/ru/routing_scheduling.md](ru/routing_scheduling.md)
- **English**: [examples/en/routing_scheduling.md](en/routing_scheduling.md)

Examples include:
- Traveling salesman problems (TSP)
- Vehicle routing problems (VRP)
- Employee shift scheduling
- Production order scheduling
- School bus routing
- Medical procedure scheduling
- Tournament scheduling
- Equipment maintenance planning

### 🏪 Retail Network Optimization (Business Case)
- **Russian**: [examples/ru/retail_optimization.md](ru/retail_optimization.md)
- **English**: [examples/en/retail_optimization.md](en/retail_optimization.md)

Comprehensive business case featuring:
- Complete retail chain optimization
- ROI 300-400% demonstration
- Multi-objective optimization
- Real-world implementation roadmap
- Risk analysis and mitigation
- Financial impact assessment

## How to Use These Examples

### For LLM Integration
These examples are designed to be used as prompts when interacting with LLMs that have access to MCP Optimizer. Simply copy the prompt text and provide it to your LLM.

### For Direct API Usage
Each example includes the corresponding API structure that can be used directly with MCP Optimizer functions.

### For Learning
Use these examples to understand different optimization problem types and how to formulate them for MCP Optimizer.

## Example Structure

Each example file contains:

1. **Description** - Overview of the optimization problem type
2. **Example Prompts** - Ready-to-use prompts for LLMs
3. **API Structure** - Technical implementation details
4. **Activation Phrases** - Common phrases that trigger optimization
5. **Applications** - Real-world use cases

## Language Versions

- **Russian (`/ru`)** - Examples in Russian with ruble-based scenarios
- **English (`/en`)** - Examples in English with dollar-based scenarios

Both versions cover the same optimization concepts and are direct translations of each other.

## Contributing

To add new examples:

1. Create the example in both `/ru` and `/en` directories
2. Ensure both versions cover the same concepts
3. Include practical, real-world scenarios
4. Provide clear prompts for LLM usage
5. Update this README with the new example

## Optimization Categories

MCP Optimizer supports 9 categories of optimization problems:

1. **Linear Programming** ✅
2. **Assignment Problems** ✅
3. **Transportation Problems** ✅
4. **Knapsack Problems** ✅
5. **Routing Problems** ✅
6. **Scheduling Problems** ✅
7. **Integer Programming** (included in other examples)
8. **Financial Optimization** ✅
9. **Production Planning** (included in other examples)
10. **Retail Network Optimization** ✅ (Comprehensive Business Case)

## Quick Start

1. Choose an example that matches your problem type
2. Copy the relevant prompt
3. Modify the data to match your specific case
4. Use with your LLM that has MCP Optimizer access
5. Review and implement the suggested solution

## Support

For questions about these examples or MCP Optimizer usage:
- 📧 Email: support@mcp-optimizer.com
- 🐛 Issues: [GitHub Issues](https://github.com/dmitryanchikov/mcp-optimizer/issues)
- 📖 Documentation: [Main README](../README.md) 