# Портфельная оптимизация - Примеры использования

## Описание
Портфельная оптимизация помогает найти оптимальное распределение инвестиций между различными активами для достижения наилучшего соотношения риска и доходности.

## Примеры промптов для LLM

### Пример 1: Базовая портфельная оптимизация
```
Помоги мне оптимизировать инвестиционный портфель с помощью MCP Optimizer.

У меня есть 1 миллион рублей для инвестирования в следующие активы:

Активы:
- Акции Сбербанка: ожидаемая доходность 12%, риск (стандартное отклонение) 18%
- Облигации ОФЗ: ожидаемая доходность 6%, риск 3%
- Акции Яндекса: ожидаемая доходность 15%, риск 25%
- Золото: ожидаемая доходность 8%, риск 12%

Требования:
- Максимальный приемлемый риск портфеля: 15%
- Минимальная ожидаемая доходность: 10%

Найди оптимальное распределение средств для минимизации риска.
```

### Пример 2: Диверсифицированный портфель
```
Используй MCP Optimizer для создания диверсифицированного портфеля.

Бюджет: 500,000 рублей

Доступные активы:
- Российские акции: доходность 14%, риск 20%
- Зарубежные акции: доходность 11%, риск 16%
- Корпоративные облигации: доходность 8%, риск 5%
- Государственные облигации: доходность 5%, риск 2%
- Недвижимость (REIT): доходность 9%, риск 10%
- Сырьевые товары: доходность 7%, риск 15%

Ограничения:
- Не более 30% в любой отдельный актив
- Минимум 10% в государственные облигации
- Максимум 40% в акции (российские + зарубежные)
- Толерантность к риску: 12%

Максимизируй ожидаемую доходность при соблюдении ограничений.
```

### Пример 3: Пенсионный портфель
```
Помоги создать консервативный пенсионный портфель с MCP Optimizer.

Сумма для инвестирования: 2,000,000 рублей
Инвестиционный горизонт: 15 лет до пенсии

Варианты инвестирования:
- Акции крупных компаний: доходность 10%, риск 15%
- Облигации федерального займа: доходность 6%, риск 3%
- Корпоративные облигации: доходность 8%, риск 6%
- Банковские депозиты: доходность 4%, риск 1%
- Индексные фонды: доходность 9%, риск 12%

Требования:
- Максимальный риск портфеля: 8%
- Минимум 20% в безрисковые активы (депозиты + ОФЗ)
- Максимум 40% в акции
- Целевая доходность: не менее 7%

Найди оптимальное распределение для достижения целей.
```

### Пример 4: Агрессивный рост портфеля
```
Создай агрессивный портфель роста с помощью MCP Optimizer.

Капитал: 300,000 рублей
Цель: максимальный рост за 5 лет

Инвестиционные возможности:
- Технологические акции: доходность 20%, риск 30%
- Акции развивающихся рынков: доходность 18%, риск 28%
- Криптовалюты: доходность 25%, риск 40%
- Стартапы (венчурные фонды): доходность 22%, риск 35%
- Высокодоходные облигации: доходность 12%, риск 15%
- Товарные фьючерсы: доходность 15%, риск 25%

Ограничения:
- Максимальный риск портфеля: 25%
- Максимум 20% в криптовалюты
- Минимум 10% в облигации для стабильности
- Не более 25% в любой отдельный актив

Максимизируй ожидаемую доходность.
```

## Структура запроса к MCP Optimizer

```python
# Пример вызова функции
result = optimize_portfolio(
    assets=[
        {"name": "Актив1", "expected_return": 0.12, "risk": 0.18},
        {"name": "Актив2", "expected_return": 0.08, "risk": 0.10},
        {"name": "Актив3", "expected_return": 0.15, "risk": 0.25}
    ],
    objective="minimize_risk",  # или "maximize_return"
    budget=1000000,
    risk_tolerance=0.15,
    min_return=0.10,
    constraints={
        "max_weight_per_asset": 0.30,
        "min_bonds": 0.20,
        "max_stocks": 0.60
    }
)
```

## Типичные фразы для активации

- "Оптимизируй мой инвестиционный портфель"
- "Найди оптимальное распределение активов"
- "Минимизируй риск при заданной доходности"
- "Максимизируй доходность при ограниченном риске"
- "Создай диверсифицированный портфель"
- "Помоги с распределением инвестиций"

## Стратегии оптимизации

1. **Минимизация риска** - при заданной целевой доходности
2. **Максимизация доходности** - при ограниченном уровне риска
3. **Максимизация коэффициента Шарпа** - лучшее соотношение риск/доходность
4. **Равновесный портфель** - баланс между всеми активами

## Применение

Портфельная оптимизация используется для:
- Личных инвестиций
- Пенсионных накоплений
- Управления активами фондов
- Корпоративных инвестиций
- Страховых резервов 